#! /usr/bin/env python3

import os, functools
from gi.repository import GLib, Gio

def sort_func(str1, str2):
    """
        str1.encode("utf8") is not required.
        Not 'cmp' function in Python3
    """
    cmpstr1 = GLib.utf8_collate_key_for_filename(str1, -1)
    cmpstr2 = GLib.utf8_collate_key_for_filename(str2, -1)
    if cmpstr1 < cmpstr2:
        return -1
    return 1

def get_file_numsort_list(dirname, extlist):
    """
        param dirname: Directory Full Path Name
        param extlist: List of Extention
        return: List in Numeric Order
    """
    files = []
    d = Gio.file_new_for_path(dirname)
    file_enumerator = d.enumerate_children(
            "standard::type,standard::is-hidden,standard::is-backup",
            Gio.FileQueryInfoFlags.NONE,
            None )
    #for info in enum:
    while True:
        info = file_enumerator.next_file(None)
        if info == None: break
        if info.get_is_hidden(): continue
        if info.get_is_backup(): continue
        if info.get_file_type() == Gio.FileType.DIRECTORY: continue
        s = info.get_name()
        if GLib.Regex.match_simple("\.({0})$".format("|".join(extlist)), s, GLib.RegexCompileFlags.CASELESS, 0):
            files.append(s)
    files.sort(key=functools.cmp_to_key(sort_func))
    return files
