#!/usr/bin/env python3

from gi.repository import Gtk, GLib, GdkPixbuf

class ComipoliThumbnail(Gtk.Dialog):
    def __init__(self, owner):
        Gtk.Dialog.__init__(self, transient_for=owner, title="Comipoli Thumbnail")
        self.owner = owner
        self.fbox = Gtk.FlowBox(
            valign=Gtk.Align.START,
            max_children_per_line=10,
            homogeneous=True,
            #activate_on_single_click=False,
            selection_mode=Gtk.SelectionMode.BROWSE)
        self.fbox.connect("child-activated", self.on_flowbox_child_activated)
        scroll = Gtk.ScrolledWindow()
        scroll.add(self.fbox)
        self.vbox.pack_start(scroll, True, True, 0)
        # size
        x, y = self.owner.get_size()
        self.resize(x, y)
        self.show_all()
        # idle
        self.gen = self.read_zipfile()
        GLib.idle_add(self.iter_idle)

    def iter_idle(self):
        try:
            next(self.gen)
            return True
        except Exception as e:
            return False

    def read_zipfile(self):
        #for num, pixbuf in enumerate(self.owner.arcive):
        l = len(self.owner.archive)
        for num in range(l):
            pixbuf = self.owner.archive[num]
            self.append_data(pixbuf, num)
            # Focus
            if num == self.owner.num:
                child = self.fbox.get_child_at_index(num)
                self.fbox.select_child(child)
                self.set_focus(child)
            yield 1

    def append_data(self, pixbuf, num):
        if pixbuf.get_width() > pixbuf.get_height():
            pix_w = self.owner.thumbnail_height
            pix_h = round(self.owner.thumbnail_height * pixbuf.get_height() / pixbuf.get_width())
        else:
            pix_w = round(self.owner.thumbnail_height * pixbuf.get_width() / pixbuf.get_height())
            pix_h = self.owner.thumbnail_height
        minp = pixbuf.scale_simple(pix_w, pix_h, GdkPixbuf.InterpType.TILES) #NEAREST
        image = Gtk.Image(pixbuf=minp, visible=True)
        label = Gtk.Label(
            label='<span color="#ff0000" background="#66ffff" background_alpha="50%">{0}</span>'.format(num+1),
            use_markup=True,
            visible=True,
            halign=Gtk.Align.CENTER,
            valign=Gtk.Align.END)
        overlay = Gtk.Overlay(visible=True)
        overlay.add(image)
        overlay.add_overlay(label)
        self.fbox.add(overlay)

    def on_flowbox_child_activated(self, fbox, child):
        num = child.get_index()
        self.owner.num = num - 1
        self.owner.change_pixbuf(1)
        self.hide()

